@@ -21,9 +21,21 @@ __author__ = 'Jürgen E. Fischer'
 __date__ = 'February 2016'
 __copyright__ = '(C) 2016, Jürgen E. Fischer'
 # This will get replaced with a git SHA1 when you do a git archive
-__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
+import warnings
 from PyQt5.uic.Compiler import indenter, compiler
 from PyQt5.uic.objcreator import widgetPluginPath
 from PyQt5.uic import properties, uiparser, Compiler
 from PyQt5.uic import *
+
+__PyQtLoadUiType = loadUiType
+
+
+def __loadUiType(*args, **kwargs):
+    with warnings.catch_warnings():
+        warnings.filterwarnings("ignore", category=DeprecationWarning)
+        return __PyQtLoadUiType(*args, **kwargs)
+
+
+loadUiType = __loadUiType
