@@ -23,13 +23,14 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 import os
 
 from qgis.PyQt.QtGui import QIcon
 
 from qgis.core import (QgsProcessingException,
+                       QgsProcessingParameterDefinition,
                        QgsProcessingParameterRasterLayer,
                        QgsProcessingParameterEnum,
                        QgsProcessingParameterString,
@@ -82,12 +83,17 @@ class gdaladdo(GdalAlgorithm):
                                                  self.tr('Resampling method'),
                                                  options=[i[0] for i in self.methods],
                                                  allowMultiple=False,
-                                                 defaultValue=0))
+                                                 defaultValue=0,
+                                                 optional=True))
         params.append(QgsProcessingParameterEnum(self.FORMAT,
                                                  self.tr('Overviews format'),
                                                  options=self.formats,
                                                  allowMultiple=False,
-                                                 defaultValue=0))
+                                                 defaultValue=0,
+                                                 optional=True))
+        for p in params:
+            p.setFlags(p.flags() | QgsProcessingParameterDefinition.FlagAdvanced)
+            self.addParameter(p)
 
         self.addOutput(QgsProcessingOutputRasterLayer(self.OUTPUT, self.tr('Pyramidized')))
 
