@@ -23,7 +23,7 @@ __copyright__ = '(C) 2013, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 import os
 
@@ -107,7 +107,7 @@ class rasterize(GdalAlgorithm):
                                                        optional=True))
 
         options_param = QgsProcessingParameterString(self.OPTIONS,
-                                                     self.tr('Additional creation parameters'),
+                                                     self.tr('Additional creation options'),
                                                      defaultValue='',
                                                      optional=True)
         options_param.setFlags(options_param.flags() | QgsProcessingParameterDefinition.FlagAdvanced)
@@ -127,7 +127,6 @@ class rasterize(GdalAlgorithm):
         init_param = QgsProcessingParameterNumber(self.INIT,
                                                   self.tr('Pre-initialize the output image with value'),
                                                   type=QgsProcessingParameterNumber.Double,
-                                                  defaultValue=0.0,
                                                   optional=True)
         init_param.setFlags(init_param.flags() | QgsProcessingParameterDefinition.FlagAdvanced)
         self.addParameter(init_param)
@@ -181,8 +180,8 @@ class rasterize(GdalAlgorithm):
         arguments.append(self.parameterAsDouble(parameters, self.WIDTH, context))
         arguments.append(self.parameterAsDouble(parameters, self.HEIGHT, context))
 
-        initValue = self.parameterAsDouble(parameters, self.INIT, context)
-        if initValue:
+        if self.INIT in parameters and parameters[self.INIT] is not None:
+            initValue = self.parameterAsDouble(parameters, self.INIT, context)
             arguments.append('-init')
             arguments.append(initValue)
 
@@ -209,6 +208,7 @@ class rasterize(GdalAlgorithm):
         arguments.append(self.TYPES[self.parameterAsEnum(parameters, self.DATA_TYPE, context)])
 
         out = self.parameterAsOutputLayer(parameters, self.OUTPUT, context)
+        self.setOutputValue(self.OUTPUT, out)
         arguments.append('-of')
         arguments.append(QgsRasterFileWriter.driverForExtension(os.path.splitext(out)[1]))
         options = self.parameterAsString(parameters, self.OPTIONS, context)
