@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 from qgis.PyQt.QtCore import QVariant
 from qgis.core import (QgsExpression,
@@ -32,6 +32,7 @@ from qgis.core import (QgsExpression,
                        QgsFeatureSink,
                        QgsField,
                        QgsDistanceArea,
+                       QgsProcessing,
                        QgsProcessingParameterFeatureSource,
                        QgsProcessingParameterEnum,
                        QgsProcessingParameterNumber,
@@ -71,13 +72,14 @@ class FieldsCalculator(QgisAlgorithm):
                            self.tr('Date')]
 
     def initAlgorithm(self, config=None):
-        self.addParameter(QgsProcessingParameterFeatureSource(self.INPUT, self.tr('Input layer')))
+        self.addParameter(QgsProcessingParameterFeatureSource(self.INPUT, self.tr('Input layer'),
+                                                              types=[QgsProcessing.TypeVector]))
         self.addParameter(QgsProcessingParameterString(self.FIELD_NAME,
                                                        self.tr('Result field name')))
         self.addParameter(QgsProcessingParameterEnum(self.FIELD_TYPE,
                                                      self.tr('Field type'), options=self.type_names))
         self.addParameter(QgsProcessingParameterNumber(self.FIELD_LENGTH,
-                                                       self.tr('Field length'), minValue=1, maxValue=255, defaultValue=10))
+                                                       self.tr('Field length'), minValue=0, defaultValue=10))
         self.addParameter(QgsProcessingParameterNumber(self.FIELD_PRECISION,
                                                        self.tr('Field precision'), minValue=0, maxValue=15, defaultValue=3))
         self.addParameter(QgsProcessingParameterBoolean(self.NEW_FIELD,
