@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 import os
 import math
@@ -101,7 +101,7 @@ class PointDistance(QgisAlgorithm):
         self.addParameter(QgsProcessingParameterEnum(self.MATRIX_TYPE,
                                                      self.tr('Output matrix type'), options=self.mat_types, defaultValue=0))
         self.addParameter(QgsProcessingParameterNumber(self.NEAREST_POINTS,
-                                                       self.tr('Use only the nearest (k) target points'), type=QgsProcessingParameterNumber.Integer, minValue=0, maxValue=9999, defaultValue=0))
+                                                       self.tr('Use only the nearest (k) target points'), type=QgsProcessingParameterNumber.Integer, minValue=0, defaultValue=0))
 
         self.addParameter(QgsProcessingParameterFeatureSink(self.OUTPUT, self.tr('Distance matrix'), QgsProcessing.TypeVectorPoint))
 
@@ -116,11 +116,17 @@ class PointDistance(QgisAlgorithm):
         if source is None:
             raise QgsProcessingException(self.invalidSourceError(parameters, self.INPUT))
 
+        if QgsWkbTypes.isMultiType(source.wkbType()):
+            raise QgsProcessingException(self.tr('Input point layer is a MultiPoint layer - first convert to single points before using this algorithm.'))
+
         source_field = self.parameterAsString(parameters, self.INPUT_FIELD, context)
         target_source = self.parameterAsSource(parameters, self.TARGET, context)
         if target_source is None:
             raise QgsProcessingException(self.invalidSourceError(parameters, self.TARGET))
 
+        if QgsWkbTypes.isMultiType(target_source.wkbType()):
+            raise QgsProcessingException(self.tr('Target point layer is a MultiPoint layer - first convert to single points before using this algorithm.'))
+
         target_field = self.parameterAsString(parameters, self.TARGET_FIELD, context)
         same_source_and_target = parameters[self.INPUT] == parameters[self.TARGET]
         matType = self.parameterAsEnum(parameters, self.MATRIX_TYPE, context)
@@ -187,7 +193,7 @@ class PointDistance(QgisAlgorithm):
                 break
 
             inGeom = inFeat.geometry()
-            inID = str(inFeat.attributes()[inIdx])
+            inID = str(inFeat[inIdx])
             featList = index.nearestNeighbor(inGeom.asPoint(), nPoints)
             distList = []
             vari = 0.0
@@ -199,7 +205,7 @@ class PointDistance(QgisAlgorithm):
                 if same_source_and_target and inFeat.id() == outFeat.id():
                     continue
 
-                outID = outFeat.attributes()[outIdx]
+                outID = outFeat[outIdx]
                 outGeom = outFeat.geometry()
                 dist = distArea.measureLine(inGeom.asPoint(),
                                             outGeom.asPoint())
