@@ -23,7 +23,7 @@ __copyright__ = '(C) 2014, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 import random
 
@@ -100,7 +100,7 @@ class RandomPointsAlongLines(QgisAlgorithm):
         fields.append(QgsField('id', QVariant.Int, '', 10, 0))
 
         (sink, dest_id) = self.parameterAsSink(parameters, self.OUTPUT, context,
-                                               fields, QgsWkbTypes.Point, source.sourceCrs())
+                                               fields, QgsWkbTypes.Point, source.sourceCrs(), QgsFeatureSink.RegeneratePrimaryKey)
         if sink is None:
             raise QgsProcessingException(self.invalidSinkError(parameters, self.OUTPUT))
 
@@ -163,7 +163,7 @@ class RandomPointsAlongLines(QgisAlgorithm):
                     f.setAttribute('id', nPoints)
                     f.setGeometry(geom)
                     sink.addFeature(f, QgsFeatureSink.FastInsert)
-                    index.insertFeature(f)
+                    index.addFeature(f)
                     points[nPoints] = p
                     nPoints += 1
                     feedback.setProgress(int(nPoints * total))
