@@ -49,7 +49,7 @@ __copyright__ = '(C) 2016 by OPENGIS.ch'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'bc43194061452b37c8a22edcb7b380055a0c4236'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 
 class RasterizeAlgorithm(QgisAlgorithm):
@@ -153,7 +153,10 @@ class RasterizeAlgorithm(QgisAlgorithm):
     def tags(self):
         return self.tr('layer,raster,convert,file,map themes,tiles,render').split(',')
 
-    # def processAlgorithm(self, progress):
+    def prepareAlgorithm(self, parameters, context, feedback):
+        self.mapSettings = qgis.utils.iface.mapCanvas().mapSettings()
+        return True
+
     def processAlgorithm(self, parameters, context, feedback):
         """Here is where the processing itself takes place."""
 
@@ -194,9 +197,11 @@ class RasterizeAlgorithm(QgisAlgorithm):
             self.OUTPUT,
             context)
 
+        project = context.project()
+
         tile_set = TileSet(map_theme, layer, extent, tile_size, mupp,
                            output_layer, make_trans,
-                           qgis.utils.iface.mapCanvas().mapSettings())
+                           self.mapSettings, project)
         tile_set.render(feedback, make_trans)
 
         return {self.OUTPUT: output_layer}
@@ -209,7 +214,7 @@ class TileSet():
     """
 
     def __init__(self, map_theme, layer, extent, tile_size, mupp, output,
-                 make_trans, map_settings):
+                 make_trans, map_settings, project):
         """
         :param map_theme:
         :param extent:
@@ -260,10 +265,14 @@ class TileSet():
         self.settings.setFlag(QgsMapSettings.RenderMapTile, True)
         self.settings.setFlag(QgsMapSettings.UseAdvancedEffects, True)
 
+        r = project.readNumEntry('Gui', '/CanvasColorRedPart', 255)[0]
+        g = project.readNumEntry('Gui', '/CanvasColorGreenPart', 255)[0]
+        b = project.readNumEntry('Gui', '/CanvasColorBluePart', 255)[0]
         if make_trans:
-            self.settings.setBackgroundColor(QColor(255, 255, 255, 0))
+            self.bgColor = QColor(r, g, b, 0)
         else:
-            self.settings.setBackgroundColor(QColor(255, 255, 255))
+            self.bgColor = QColor(r, g, b)
+        self.settings.setBackgroundColor(self.bgColor)
 
         if QgsProject.instance().mapThemeCollection().hasMapTheme(map_theme):
             self.settings.setLayers(
@@ -300,11 +309,9 @@ class TileSet():
         """
 
         if make_trans:
-            background_color = QColor(255, 255, 255, 0)
-            self.image.fill(background_color.rgba())
+            self.image.fill(self.bgColor.rgba())
         else:
-            background_color = QColor(255, 255, 255)
-            self.image.fill(background_color.rgb())
+            self.image.fill(self.bgColor.rgb())
 
         painter = QPainter(self.image)
 
