@@ -23,7 +23,7 @@ __copyright__ = '(C) 2013, Alexander Bruy'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 import os
 import re
@@ -41,9 +41,10 @@ from qgis.core import (Qgis,
                        QgsProperty,
                        QgsProject,
                        QgsMessageLog,
+                       QgsMapLayer,
                        QgsProcessingOutputLayerDefinition)
-from qgis.gui import QgsEncodingFileDialog
-from qgis.utils import OverrideCursor
+from qgis.gui import QgsEncodingFileDialog, QgsGui
+from qgis.utils import OverrideCursor, iface
 
 from processing.core.ProcessingConfig import ProcessingConfig
 from processing.core.ProcessingLog import ProcessingLog
@@ -86,6 +87,12 @@ class FieldsCalculatorDialog(BASE, WIDGET):
         self.layer = None
 
         self.cmbInputLayer.setFilters(QgsMapLayerProxyModel.VectorLayer)
+        try:
+            if iface.activeLayer().type() == QgsMapLayer.VectorLayer:
+                self.cmbInputLayer.setLayer(iface.activeLayer())
+        except:
+            pass
+
         self.cmbInputLayer.layerChanged.connect(self.updateLayer)
         self.btnBrowse.clicked.connect(self.selectFile)
         self.mNewFieldGroupBox.toggled.connect(self.toggleExistingGroup)
@@ -240,6 +247,7 @@ class FieldsCalculatorDialog(BASE, WIDGET):
 
                 context = dataobjects.createContext()
                 ProcessingLog.addToLog(self.alg.asPythonCommand(parameters, context))
+                QgsGui.instance().processingRecentAlgorithmLog().push(self.alg.id())
 
                 self.executed, results = execute(self.alg, parameters, context, self.feedback)
                 self.setPercentage(0)
@@ -248,7 +256,8 @@ class FieldsCalculatorDialog(BASE, WIDGET):
                     handleAlgorithmResults(self.alg,
                                            context,
                                            self.feedback,
-                                           not keepOpen)
+                                           not keepOpen,
+                                           parameters)
                 self._wasExecuted = self.executed or self._wasExecuted
                 if not keepOpen:
                     QDialog.reject(self)
