@@ -21,17 +21,20 @@ __author__ = 'Victor Olaya'
 __date__ = 'November 2016'
 __copyright__ = '(C) 2016, Victor Olaya'
 # This will get replaced with a git SHA1 when you do a git archive
-__revision__ = '26842169e9367434a27a70ab0df0bd4ba6ad1d7a'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 import os
 from functools import partial
 import re
 import json
 
+from qgis.utils import iface
 from qgis.PyQt import uic
+from qgis.PyQt.QtCore import Qt
 from qgis.PyQt.QtGui import QTextCursor
 from qgis.PyQt.QtWidgets import (QLineEdit, QPushButton, QLabel,
-                                 QComboBox, QSpacerItem, QSizePolicy)
+                                 QComboBox, QSpacerItem, QSizePolicy,
+                                 QListWidgetItem)
 
 from qgis.core import (QgsProcessingUtils,
                        QgsProcessingParameterDefinition,
@@ -44,9 +47,10 @@ from processing.gui.BatchInputSelectionPanel import BatchInputSelectionPanel
 from processing.tools import dataobjects
 from processing.tools.system import userFolder
 
-
 from processing.gui.wrappers import InvalidParameterValue
 
+from qgis.analysis import QgsRasterCalculatorEntry
+
 pluginPath = os.path.dirname(__file__)
 WIDGET_ADD_NEW, BASE_ADD_NEW = uic.loadUiType(
     os.path.join(pluginPath, 'AddNewExpressionDialog.ui'))
@@ -186,8 +190,20 @@ class ExpressionWidget(BASE, WIDGET):
     def setList(self, options):
         self.options = options
         self.listWidget.clear()
-        for opt in options.keys():
-            self.listWidget.addItem(opt)
+        entries = QgsRasterCalculatorEntry.rasterEntries()
+
+        def _find_source(name):
+            for entry in entries:
+                if entry.ref == name:
+                    return entry.raster.source()
+            return ''
+
+        for name in options.keys():
+            item = QListWidgetItem(name, self.listWidget)
+            tooltip = _find_source(name)
+            if tooltip:
+                item.setData(Qt.ToolTipRole, tooltip)
+            self.listWidget.addItem(item)
 
     def setValue(self, value):
         self.text.setPlainText(value)
@@ -201,29 +217,28 @@ class ExpressionWidgetWrapper(WidgetWrapper):
     def _panel(self, options):
         return ExpressionWidget(options)
 
+    def _get_options(self):
+        entries = QgsRasterCalculatorEntry.rasterEntries()
+        options = {}
+        for entry in entries:
+            options[entry.ref] = entry.ref
+        return options
+
     def createWidget(self):
         if self.dialogType == DIALOG_STANDARD:
-            layers = QgsProcessingUtils.compatibleRasterLayers(QgsProject.instance(), False)
-            options = {}
-            for lyr in layers:
-                for n in range(lyr.bandCount()):
-                    name = '{:s}@{:d}'.format(lyr.name(), n + 1)
-                    options[name] = name
-            return self._panel(options)
+            if iface is not None and iface.layerTreeView() is not None and iface.layerTreeView().layerTreeModel() is not None:
+                iface.layerTreeView().layerTreeModel().dataChanged.connect(self.refresh)
+            return self._panel(self._get_options())
         elif self.dialogType == DIALOG_BATCH:
             return QLineEdit()
         else:
             layers = self.dialog.getAvailableValuesOfType([QgsProcessingParameterRasterLayer], [QgsProcessingOutputRasterLayer])
-            options = {self.dialog.resolveValueDescription(lyr): "{}@1".format(lyr) for lyr in layers}
-            return self._panel(options)
+            options = {self.dialog.resolveValueDescription(lyr): "{}@1".format(self.dialog.resolveValueDescription(lyr)) for lyr in layers}
+            self.widget = self._panel(options)
+            return self.widget
 
-    def refresh(self):
-        layers = QgsProcessingUtils.compatibleRasterLayers(QgsProject.instance())
-        options = {}
-        for lyr in layers:
-            for n in range(lyr.bandCount()):
-                options[lyr.name()] = '{:s}@{:d}'.format(lyr.name(), n + 1)
-        self.widget.setList(options)
+    def refresh(self, *args):
+        self.widget.setList(self._get_options())
 
     def setValue(self, value):
         if self.dialogType == DIALOG_STANDARD:
@@ -234,7 +249,7 @@ class ExpressionWidgetWrapper(WidgetWrapper):
             self.widget.setValue(value)
 
     def value(self):
-        if self.dialogType in DIALOG_STANDARD:
+        if self.dialogType == DIALOG_STANDARD:
             return self.widget.value()
         elif self.dialogType == DIALOG_BATCH:
             return self.widget.text()
@@ -246,7 +261,7 @@ class LayersListWidgetWrapper(WidgetWrapper):
 
     def createWidget(self):
         if self.dialogType == DIALOG_BATCH:
-            widget = BatchInputSelectionPanel(self.param, self.row, self.col, self.dialog)
+            widget = BatchInputSelectionPanel(self.parameterDefinition(), self.row, self.col, self.dialog)
             widget.valueChanged.connect(lambda: self.widgetValueHasChanged.emit(self))
             return widget
         else:
@@ -273,6 +288,6 @@ class LayersListWidgetWrapper(WidgetWrapper):
         else:
             options = self._getOptions()
             values = [options[i] for i in self.widget.selectedoptions]
-            if len(values) == 0 and not self.param.flags() & QgsProcessingParameterDefinition.FlagOptional:
+            if len(values) == 0 and not self.parameterDefinition().flags() & QgsProcessingParameterDefinition.FlagOptional:
                 raise InvalidParameterValue()
             return values
