@@ -23,7 +23,7 @@ __copyright__ = '(C) 2012, Victor Olaya'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = 'f6ddc62fdb8ae589d3827e84d0c25bf669931040'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 from pprint import pformat
 import time
@@ -168,7 +168,7 @@ class BatchAlgorithmDialog(QgsProcessingAlgorithmDialogBase):
                 else:
                     break
 
-                handleAlgorithmResults(self.algorithm(), context, multi_feedback, False)
+                handleAlgorithmResults(self.algorithm(), context, multi_feedback, False, parameters)
 
         feedback.pushInfo(self.tr('Batch execution completed in {0:0.2f} seconds'.format(time.time() - start_time)))
         task = None
