@@ -23,7 +23,7 @@ __copyright__ = '(C) 2018, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 import os
 from qgis.PyQt.QtWidgets import QFileDialog
@@ -51,7 +51,7 @@ class OpenScriptFromFileAction(ToolboxAction):
         lastDir = settings.value('Processing/lastScriptsDir', '')
         filename, selected_filter = QFileDialog.getOpenFileName(self.toolbox,
                                                                 self.tr('Open Script', 'AddScriptFromFileAction'), lastDir,
-                                                                self.tr('Script files (*.py)', 'AddScriptFromFileAction'))
+                                                                self.tr('Processing scripts (*.py *.PY)', 'AddScriptFromFileAction'))
         if filename:
             settings.setValue('Processing/lastScriptsDir',
                               QFileInfo(filename).absoluteDir().absolutePath())
