@@ -23,7 +23,7 @@ __copyright__ = '(C) 2017, Nyall Dawson'
 
 # This will get replaced with a git SHA1 when you do a git archive
 
-__revision__ = '9b176802e5512bc310765d8ebe4e44b5f4663453'
+__revision__ = '93e761dd2396af21db9bb93e26d7cba680c906ca'
 
 from qgis.testing import start_app, unittest
 from qgis.core import (QgsApplication,
@@ -35,6 +35,7 @@ from qgis.core import (QgsApplication,
                        QgsProcessingParameterFolderDestination,
                        QgsProcessingParameterVectorDestination,
                        QgsProcessingParameterRasterDestination,
+                       QgsProcessingParameterRange,
                        QgsVectorLayer,
                        QgsProject)
 from qgis.analysis import QgsNativeAlgorithms
@@ -54,7 +55,7 @@ testDataPath = os.path.join(os.path.dirname(__file__), 'testdata')
 class AlgorithmDialogTest(unittest.TestCase):
 
     def testCreation(self):
-        alg = QgsApplication.processingRegistry().algorithmById('native:centroids')
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
         a = AlgorithmDialog(alg)
         self.assertEqual(a.mainWidget().alg, alg)
 
@@ -66,7 +67,7 @@ class WrappersTest(unittest.TestCase):
         ProcessingConfig.initialize()
 
     def checkConstructWrapper(self, param, expected_wrapper_class):
-        alg = QgsApplication.processingRegistry().algorithmById('native:centroids')
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
 
         # algorithm dialog
         dlg = AlgorithmDialog(alg)
@@ -76,6 +77,7 @@ class WrappersTest(unittest.TestCase):
         self.assertEqual(wrapper.dialog, dlg)
         self.assertIsNotNone(wrapper.widget)
 
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
         # batch dialog
         dlg = BatchAlgorithmDialog(alg)
         wrapper = WidgetWrapperFactory.create_wrapper_from_class(param, dlg)
@@ -84,6 +86,8 @@ class WrappersTest(unittest.TestCase):
         self.assertEqual(wrapper.dialog, dlg)
         self.assertIsNotNone(wrapper.widget)
 
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
+
         # modeler dialog
         model = QgsProcessingModelAlgorithm()
         dlg = ModelerParametersDialog(alg, model)
@@ -137,7 +141,7 @@ class WrappersTest(unittest.TestCase):
         self.assertTrue(layer.isValid())
         QgsProject.instance().addMapLayer(layer)
 
-        alg = QgsApplication.processingRegistry().algorithmById('native:centroids')
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
         dlg = AlgorithmDialog(alg)
         param = QgsProcessingParameterFeatureSource('test')
         wrapper = FeatureSourceWidgetWrapper(param, dlg)
@@ -170,13 +174,76 @@ class WrappersTest(unittest.TestCase):
         value = wrapper.value()
         self.assertEqual(value, '/home/my_layer.shp')
 
+    def testRange(self):
+        # minimal test to check if wrapper generate GUI for each processign context
+        self.checkConstructWrapper(QgsProcessingParameterRange('test'), RangeWidgetWrapper)
+
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
+        dlg = AlgorithmDialog(alg)
+        param = QgsProcessingParameterRange(
+            name='test',
+            description='test',
+            type=QgsProcessingParameterNumber.Double,
+            defaultValue="0.0,100.0")
+
+        wrapper = RangeWidgetWrapper(param, dlg)
+        widget = wrapper.createWidget()
+
+        # range values check
+
+        # check initial value
+        self.assertEqual(widget.getValue(), '0.0,100.0')
+        # check set/get
+        widget.setValue("100.0,200.0")
+        self.assertEqual(widget.getValue(), '100.0,200.0')
+        # check that min/max are mutually adapted
+        widget.setValue("200.0,100.0")
+        self.assertEqual(widget.getValue(), '100.0,100.0')
+        widget.spnMax.setValue(50)
+        self.assertEqual(widget.getValue(), '50.0,50.0')
+        widget.spnMin.setValue(100)
+        self.assertEqual(widget.getValue(), '100.0,100.0')
+
+        # check for integers
+        param = QgsProcessingParameterRange(
+            name='test',
+            description='test',
+            type=QgsProcessingParameterNumber.Integer,
+            defaultValue="0.1,100.1")
+
+        wrapper = RangeWidgetWrapper(param, dlg)
+        widget = wrapper.createWidget()
+
+        # range values check
+
+        # check initial value
+        self.assertEqual(widget.getValue(), '0.0,100.0')
+        # check rounding
+        widget.setValue("100.1,200.1")
+        self.assertEqual(widget.getValue(), '100.0,200.0')
+        widget.setValue("100.6,200.6")
+        self.assertEqual(widget.getValue(), '101.0,201.0')
+        # check set/get
+        widget.setValue("100.1,200.1")
+        self.assertEqual(widget.getValue(), '100.0,200.0')
+        # check that min/max are mutually adapted
+        widget.setValue("200.1,100.1")
+        self.assertEqual(widget.getValue(), '100.0,100.0')
+        widget.spnMax.setValue(50.1)
+        self.assertEqual(widget.getValue(), '50.0,50.0')
+        widget.spnMin.setValue(100.1)
+        self.assertEqual(widget.getValue(), '100.0,100.0')
+
     def testMapLayer(self):
         self.checkConstructWrapper(QgsProcessingParameterMapLayer('test'), MapLayerWidgetWrapper)
 
+    def testMeshLayer(self):
+        self.checkConstructWrapper(QgsProcessingParameterMeshLayer('test'), MeshWidgetWrapper)
+
     def testDistance(self):
         self.checkConstructWrapper(QgsProcessingParameterDistance('test'), DistanceWidgetWrapper)
 
-        alg = QgsApplication.processingRegistry().algorithmById('native:centroids')
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
         dlg = AlgorithmDialog(alg)
         param = QgsProcessingParameterDistance('test')
         wrapper = DistanceWidgetWrapper(param, dlg)
@@ -189,42 +256,79 @@ class WrappersTest(unittest.TestCase):
         widget.setUnitParameterValue('EPSG:3111')
         self.assertEqual(widget.label.text(), 'meters')
         self.assertFalse(widget.warning_label.isVisible())
+        self.assertTrue(widget.units_combo.isVisible())
+        self.assertFalse(widget.label.isVisible())
+        self.assertEqual(widget.units_combo.currentData(), QgsUnitTypes.DistanceMeters)
+
         widget.setUnitParameterValue('EPSG:4326')
         self.assertEqual(widget.label.text(), 'degrees')
         self.assertTrue(widget.warning_label.isVisible())
+        self.assertFalse(widget.units_combo.isVisible())
+        self.assertTrue(widget.label.isVisible())
+
         widget.setUnitParameterValue(QgsCoordinateReferenceSystem('EPSG:3111'))
         self.assertEqual(widget.label.text(), 'meters')
         self.assertFalse(widget.warning_label.isVisible())
+        self.assertTrue(widget.units_combo.isVisible())
+        self.assertFalse(widget.label.isVisible())
+        self.assertEqual(widget.units_combo.currentData(), QgsUnitTypes.DistanceMeters)
+
         widget.setUnitParameterValue(QgsCoordinateReferenceSystem('EPSG:4326'))
         self.assertEqual(widget.label.text(), 'degrees')
         self.assertTrue(widget.warning_label.isVisible())
+        self.assertFalse(widget.units_combo.isVisible())
+        self.assertTrue(widget.label.isVisible())
 
         # layer values
         vl = QgsVectorLayer("Polygon?crs=epsg:3111&field=pk:int", "vl", "memory")
         widget.setUnitParameterValue(vl)
         self.assertEqual(widget.label.text(), 'meters')
         self.assertFalse(widget.warning_label.isVisible())
+        self.assertTrue(widget.units_combo.isVisible())
+        self.assertFalse(widget.label.isVisible())
+        self.assertEqual(widget.units_combo.currentData(), QgsUnitTypes.DistanceMeters)
+
         vl2 = QgsVectorLayer("Polygon?crs=epsg:4326&field=pk:int", "vl", "memory")
         widget.setUnitParameterValue(vl2)
         self.assertEqual(widget.label.text(), 'degrees')
         self.assertTrue(widget.warning_label.isVisible())
+        self.assertFalse(widget.units_combo.isVisible())
+        self.assertTrue(widget.label.isVisible())
 
         # unresolvable values
         widget.setUnitParameterValue(vl.id())
         self.assertEqual(widget.label.text(), '<unknown>')
         self.assertFalse(widget.warning_label.isVisible())
+        self.assertFalse(widget.units_combo.isVisible())
+        self.assertTrue(widget.label.isVisible())
+
         # resolvable text value
         QgsProject.instance().addMapLayer(vl)
         widget.setUnitParameterValue(vl.id())
         self.assertEqual(widget.label.text(), 'meters')
         self.assertFalse(widget.warning_label.isVisible())
+        self.assertTrue(widget.units_combo.isVisible())
+        self.assertFalse(widget.label.isVisible())
+        self.assertEqual(widget.units_combo.currentData(), QgsUnitTypes.DistanceMeters)
+
+        widget.setValue(5)
+        self.assertEqual(widget.getValue(), 5)
+        widget.units_combo.setCurrentIndex(widget.units_combo.findData(QgsUnitTypes.DistanceKilometers))
+        self.assertEqual(widget.getValue(), 5000)
+        widget.setValue(2)
+        self.assertEqual(widget.getValue(), 2000)
+
+        widget.setUnitParameterValue(vl.id())
+        self.assertEqual(widget.getValue(), 2)
+        widget.setValue(5)
+        self.assertEqual(widget.getValue(), 5)
 
         widget.deleteLater()
 
     def testMatrix(self):
         self.checkConstructWrapper(QgsProcessingParameterMatrix('test'), FixedTableWidgetWrapper)
 
-        alg = QgsApplication.processingRegistry().algorithmById('native:centroids')
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
         dlg = AlgorithmDialog(alg)
         param = QgsProcessingParameterMatrix('test', 'test', 2, True, ['x', 'y'], [['a', 'b'], ['c', 'd']])
         wrapper = FixedTableWidgetWrapper(param, dlg)
@@ -248,14 +352,20 @@ class WrappersTest(unittest.TestCase):
 
     def testFeatureSink(self):
         param = QgsProcessingParameterFeatureSink('test')
-        alg = QgsApplication.processingRegistry().algorithmById('native:centroids')
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
         panel = DestinationSelectionPanel(param, alg)
 
+        panel.setValue(QgsProcessing.TEMPORARY_OUTPUT)
+        v = panel.getValue()
+        self.assertIsInstance(v, QgsProcessingOutputLayerDefinition)
+        self.assertEqual(v.createOptions, {'fileEncoding': 'System'})
+        self.assertEqual(v.sink.staticValue(), QgsProcessing.TEMPORARY_OUTPUT)
+
         panel.setValue('memory:')
         v = panel.getValue()
         self.assertIsInstance(v, QgsProcessingOutputLayerDefinition)
         self.assertEqual(v.createOptions, {'fileEncoding': 'System'})
-        self.assertEqual(v.sink.staticValue(), 'memory:')
+        self.assertEqual(v.sink.staticValue(), QgsProcessing.TEMPORARY_OUTPUT)
 
         panel.setValue('''ogr:dbname='/me/a.gpkg' table="d" (geom) sql=''')
         v = panel.getValue()
@@ -284,9 +394,14 @@ class WrappersTest(unittest.TestCase):
 
     def testVectorDestination(self):
         param = QgsProcessingParameterVectorDestination('test')
-        alg = QgsApplication.processingRegistry().algorithmById('native:centroids')
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
         panel = DestinationSelectionPanel(param, alg)
 
+        panel.setValue(QgsProcessing.TEMPORARY_OUTPUT)
+        v = panel.getValue()
+        self.assertIsInstance(v, QgsProcessingOutputLayerDefinition)
+        self.assertEqual(v.sink.staticValue(), QgsProcessing.TEMPORARY_OUTPUT)
+
         panel.setValue('''ogr:dbname='/me/a.gpkg' table="d" (geom) sql=''')
         v = panel.getValue()
         self.assertIsInstance(v, QgsProcessingOutputLayerDefinition)
@@ -314,7 +429,7 @@ class WrappersTest(unittest.TestCase):
 
     def testRasterDestination(self):
         param = QgsProcessingParameterRasterDestination('test')
-        alg = QgsApplication.processingRegistry().algorithmById('native:centroids')
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
         panel = DestinationSelectionPanel(param, alg)
 
         panel.setValue('/home/me/test.tif')
@@ -323,6 +438,11 @@ class WrappersTest(unittest.TestCase):
         self.assertEqual(v.createOptions, {'fileEncoding': 'System'})
         self.assertEqual(v.sink.staticValue(), '/home/me/test.tif')
 
+        panel.setValue(QgsProcessing.TEMPORARY_OUTPUT)
+        v = panel.getValue()
+        self.assertIsInstance(v, QgsProcessingOutputLayerDefinition)
+        self.assertEqual(v.sink.staticValue(), QgsProcessing.TEMPORARY_OUTPUT)
+
         ProcessingConfig.setSettingValue(ProcessingConfig.OUTPUT_FOLDER, testDataPath)
         panel.setValue('test.tif')
         v = panel.getValue()
@@ -332,7 +452,7 @@ class WrappersTest(unittest.TestCase):
 
     def testFolderDestination(self):
         param = QgsProcessingParameterFolderDestination('test')
-        alg = QgsApplication.processingRegistry().algorithmById('native:centroids')
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
         panel = DestinationSelectionPanel(param, alg)
 
         panel.setValue('/home/me/test.tif')
@@ -346,7 +466,7 @@ class WrappersTest(unittest.TestCase):
 
     def testFileDestination(self):
         param = QgsProcessingParameterFileDestination('test')
-        alg = QgsApplication.processingRegistry().algorithmById('native:centroids')
+        alg = QgsApplication.processingRegistry().createAlgorithmById('native:centroids')
         panel = DestinationSelectionPanel(param, alg)
 
         panel.setValue('/home/me/test.tif')
